Re: [PATCH v2] xdiff/xprepare: improve O(n*m) performance in xdl_cleanup_records()
- From
Tay Ray Chuan <rctay89@gmail.com>
- Date
- Aug 17, 2011, 15:55 UTC
- Message-ID
- <CALUzUxovdmhnRKPaEq01-q0pvez91s_Z_rHWg-FkwcU0VD3HQQ@mail.gmail.com>
- In-Reply-To
- <20110817052147.GA11253@sigill.intra.peff.net>
On Wed, Aug 17, 2011 at 1:21 PM, Jeff King <peff@peff.net> wrote:
> Wait, what? It was using 0 seconds of user time before, but still taking > 8.5 seconds? What was it doing? Did you actually warm up your disk cache > before taking these measurements?
Three runs on the same machine, after a restart.
$ time git show >/dev/null
real 0m6.505s user 0m0.031s sys 0m0.015s
rctay@TEST-123 /tmp/slono $ time git show >/dev/null
real 0m5.429s user 0m0.000s sys 0m0.031s
rctay@TEST-123 /tmp/slono $ time git show >/dev/null
real 0m5.336s user 0m0.000s sys 0m0.016s
-- Cheers, Ray Chuan